@@ -17,4 +17,4 @@ class Response:
     status_code: int
     headers: dict[str, str]
     request_body: bytes | str | None
-    raw: bytes
+    tell_position: int
